Clojure only.

missinterpret.flows.pedestal.handler


new-handlerclj

(new-handler wf)

Returns a handler function which returns a response map with the values of the result of running the workflow which processes the request which must return a response map

Returns a handler function which returns a response map
with the values of the result of running the workflow
which processes the request which must return a
response map
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries