missinterpret.flows.pedestal.interceptor


new-interceptorclj

(new-interceptor wf)
(new-interceptor wf leave-fn)
(new-interceptor wf leave-fn error-fn)

Returns an interceptor with an enter function which returns the result of a workflow which processes the context.

Returns an interceptor with an enter function which
returns the result of a workflow which processes the
context.
raw docstring

to-flowclj

(to-flow interceptor)

cljdoc builds & hosts documentation for Clojure/Script libraries