missinterpret.flows.pedestal.route


defrouteclj

(defroute p-route & opts)

Define a Flows-compatible Pedestal route.

Options are all available attributes which conform to the WorkflowOpts spec.

Define a Flows-compatible Pedestal route.

Options are all available attributes which
conform to the WorkflowOpts spec.
raw docstring

flowsclj

(flows p-route)

Returns a vector of the flows defined by the defined route that is the workflow definition.

Returns a vector of the flows defined by the defined route that
is the workflow definition.
raw docstring

route-workflowclj

(route-workflow p-route definition opts)

wf-definitionclj

(wf-definition func)

Converts the interceptor 'definition' into a vector of flows

Converts the interceptor 'definition' into a vector of flows
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries