missinterpret.flows.system.workflow


flowifyclj

(flowify catalog log-fn args node)

Converts the argument into an appropriate flow.

  • flow or workflow: pass-through
  • fn: returns a fn-flow (optionally uses result pipelining via expand-flow)
  • else: lookup flow in catalog

Note: All workflows are returned unloaded to ensure that each are loaded with an isolated stream topology.

Converts the argument into an appropriate flow.

- flow or workflow: pass-through
- fn: returns a fn-flow (optionally uses result pipelining via expand-flow)
- else: lookup flow in catalog

Note: All workflows are returned unloaded to ensure that each
      are loaded with an isolated stream topology.
raw docstring

loadclj

(load catalog {:workflow/keys [log-fn] :as wf})

Returns a loaded workflow by preparing its definition by ensuring that all nodes in the definition can either be converted into flows or loaded workflows compatible with the core load-streams function.

This function expects that the catalog contains all named references in the definition to be either flows, or workflows which have a definition with nodes which also follow the contraints.

The steps are:

  1. Flowify all nodes in the definition
  2. Flow: return it
  3. Workflow: Loaded - return it
  4. Workflow: Unloaded - load it
  5. Else: throw anomaly

Notes: All workflows returned will have a stream topology which is isolated. That means that any named workflow reference load that node instead of re-using the streams in the catalog.

Returns a loaded workflow by preparing its definition
 by ensuring that all nodes in the definition can either
 be converted into flows or loaded workflows compatible
 with the core load-streams function.

 This function expects that the catalog contains all
 named references in the definition to be either flows,
 or workflows which have a definition with nodes which also
 follow the contraints.

 The steps are:
  1. Flowify all nodes in the definition
  2. Flow: return it
  4. Workflow: Loaded - return it
  5. Workflow: Unloaded - load it
  6. Else: throw anomaly

Notes:
 All workflows returned will have a stream topology which is
 isolated. That means that any named workflow reference load that
 node instead of re-using the streams in the catalog.
raw docstring

lookup-nodeclj

(lookup-node {:flows.runtime/keys [flows workflows] :as catalog} id)

Looks up the flow or workflow which has the id. Throws an exception if there is no match.

Looks up the flow or workflow which has the id. Throws an exception
if there is no match.
raw docstring

try-loadclj

(try-load catalog {:workflow/keys [lazy-load] :as wf})

Returns a loaded workflow if it is not marked as lazy/defer.

Returns a loaded workflow if it is not marked as lazy/defer.
raw docstring

validate-workflow-graphclj

(validate-workflow-graph wf-catalog {:workflow/keys [log-fn] :as wf})
(validate-workflow-graph wf-catalog wf log-fn graph)

Returns the dependency graph of the workflow definition as a seq of ids sorted in topological order.

Validates that if the workflows definition has references that the DAG of its nested dependencies is not cyclic, throwing an exception when a back reference is encountered.

NOTE: This requires that all worklfows in the catalog have definitions that only have references which exists in the catalog. This means it does not attempt to validate circular references that may appear in a workflow embeded in a definition.

Returns the dependency graph of the workflow definition
 as a seq of ids sorted in topological order.

 Validates that if the workflows definition has references
 that the DAG of its nested dependencies is not cyclic,
 throwing an exception when a back reference is encountered.

NOTE: This requires that all worklfows in the catalog
      have definitions that only have references which
      exists in the catalog. This means it does not
      attempt to validate circular references that may
      appear in a workflow embeded in a definition.
raw docstring

workflow-refsclj

(workflow-refs catalog workflow)

Returns a seq of the workflow reference ids in the workflow definition or nil if none are present

Returns a seq of the workflow reference ids in the
workflow definition or nil if none are present
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries