(flow flow in out)Uses clojure.test to validate that the Flow is valid, can be loaded
and returns the expected output.
Uses `clojure.test` to validate that the Flow is valid, can be loaded and returns the expected output.
(start-fixture flows-definition f)A fixture to be used with clojure.test/use-fixtures which
ensures that the flows system is loaded the flows-definition
for the scope of the test(s).
A fixture to be used with `clojure.test/use-fixtures` which ensures that the flows system is loaded the flows-definition for the scope of the test(s).
(state-clean-fixture f)A fixture to be used with clojure.test/use-fixtures which
ensures that the flows system state is not loaded for the scope
of the test(s).
A fixture to be used with `clojure.test/use-fixtures` which ensures that the flows system state is not loaded for the scope of the test(s).
(workflow workflow in out)Uses clojure.test to validate that the Workflow is valid, can be loaded
and returns the expected output.
Important If the workflow's definition has any references either directly or via embedded workflows the flows system must be started with the dependencies.
Use the start-fixture with clojure.test/use-fixtures feature.
Example:
(use-fixtures :once (partial start-fixture my-flows-definition))
Uses `clojure.test` to validate that the Workflow is valid, can be loaded and returns the expected output. *Important* If the workflow's definition has any references either directly or via embedded workflows the flows system must be started with the dependencies. Use the `start-fixture` with `clojure.test/use-fixtures` feature. Example: (use-fixtures :once (partial start-fixture my-flows-definition))
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |