missinterpret.flows.xflow


->fnclj

(->fn fn-arg)

Returns a callback fn compatible with xflow which adds the result of fn-arg to the sink via put!. If an exception is thrown it is wrapped as an anomaly and is returned. core/invoke will re-throw.

Returns a callback fn compatible with xflow which adds the result of `fn-arg` to the sink via `put!`.
If an exception is thrown it is wrapped as an anomaly and is returned. `core/invoke` will re-throw.
raw docstring

defaultclj

(default default-fn)

Returns a callback fn compatible with xflow which merges the results of the default-fn into the argument.

Returns a callback fn compatible with xflow which merges the results of the `default-fn` into
the argument.
raw docstring

fn-expandclj

(fn-expand fn-arg)

Returns a callback fn compatible with xflow which adds the result of fn-arg to the sink. Supports a single result or a sequence of values which are expanded by being added to the sink via put-all!

Returns a callback fn compatible with xflow which adds the result of `fn-arg` to the sink.
Supports a single result or a sequence of values which are expanded by being added to
the sink via `put-all!`
raw docstring

xflowclj

(xflow id xform)

Returns a flow using connect-via with the passed xform functions which must have arity 2: [sink element] and return a function with the same arity.

Optionally will add the default-fn.

Returns a flow using `connect-via` with the passed xform functions
which must have arity 2: [sink element] and return a function
with the same arity.

 Optionally will add the default-fn.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries