(conj-default-flow coll node opts)(conj-leave-flow coll flow)(connect-node {:workflow/keys [id log-fn] :as workflow} node args)Connects the sink of one flow as the source of the next updating the workflow.
Note: This operates on the inverse of the convention for streams. i.e. source
Connects the sink of one flow as the source of the next
updating the workflow.
Note: This operates on the inverse of the convention
for streams. i.e. source (flowify arg & {:flow/keys [expand] :or {expand false} :as opts})Converts the argument into an appropriate flow.
Converts the argument into an appropriate flow. - flow or workflow: pass-through - fn: returns a fn-flow (optionally uses result pipelining via expand-flow) - else: throws an anomaly
(fn-flow fn-arg & opts)Returns a flow map for a fn which wraps its execution to conform to the stream model.
Returns a flow map for a fn which wraps its execution to conform to the stream model.
(has-embedded-workflows? node)(interceptor-order definition & opts)When :flow/order is :interceptor the function adds the leave-fn of all flows
which are set to the end of the definition in reverse order of appearance
to follow the interceptor chain logic.
See: http://pedestal.io/pedestal/0.7/guides/what-is-an-interceptor.html#_transition_from_enter_to_leave
When :flow/order is `:interceptor` the function adds the leave-fn of all flows which are set to the end of the definition in reverse order of appearance to follow the interceptor chain logic. See: http://pedestal.io/pedestal/0.7/guides/what-is-an-interceptor.html#_transition_from_enter_to_leave
(linear-order definition & opts)Updates the definition assuming linear ordering of nodes to include optional functions as flows.
Note:
When :workflow/default-fn is present and :workflow/map-coll is true
the flow is not added but applied by map-collection-stream.
This avoids the failure that occurs by attempting to apply the default value to the coll element which always fails.
Updates the definition assuming linear ordering of nodes to include optional functions as flows. Note: When `:workflow/default-fn` is present and `:workflow/map-coll` is `true` the flow is not added but applied by `map-collection-stream`. This avoids the failure that occurs by attempting to apply the default value to the coll element which always fails.
(map-collection-stream {:workflow/keys [log-fn id default-fn] :as loaded-wf})Analogous to clojure map.
Enriches the loaded workflow to handle elements which can be converted into a vector by applying the loaded wf stream to each entity in the coll.
Note:
When :workflow/default-fn is present it is applied to each
item in the vector of values.
Analogous to clojure `map`. Enriches the loaded workflow to handle elements which can be converted into a vector by applying the loaded wf stream to each entity in the coll. Note: When `:workflow/default-fn` is present it is applied to each item in the vector of values.
(set-log-fn wf log-fn)(unload-workflow wf)(validate-topology definition)Checks that the entries of the workflow definition to be processed by workflow-factory
is a seq, isn't empty, has a recognized type, any dependent workflow is loaded.
Checks that the entries of the workflow definition to be processed by `workflow-factory` is a seq, isn't empty, has a recognized type, any dependent workflow is loaded.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |