missinterpret.flows.core


conj-default-flowclj

(conj-default-flow coll flow opts)

conj-leave-flowclj

(conj-leave-flow coll flow)

connect-nodeclj

(connect-node {:workflow/keys [log-fn] :as workflow} node args)

Connects the sink of one flow as the source of the next updating the workflow.

Note: This operates on the inverse of the convention for streams. i.e. source

Connects the sink of one flow as the source of the next
updating the workflow.

Note: This operates on the inverse of the convention
      for streams. i.e. source 
raw docstring

flowifyclj

(flowify arg & {:flow/keys [expand] :or {expand false} :as opts})

Converts the argument into an appropriate flow.

  • flow or workflow: pass-through
  • fn: returns a fn-flow (optionally uses result pipelining via expand-flow)
  • else: throws an anomaly
Converts the argument into an appropriate flow.

- flow or workflow: pass-through
- fn: returns a fn-flow (optionally uses result pipelining via expand-flow)
- else: throws an anomaly
raw docstring

fn-flowclj

(fn-flow fn-arg & opts)

Returns a flow map for a fn which wraps its execution to conform to the stream model.

Returns a flow map for a fn which wraps its execution to conform to the
stream model.
raw docstring

has-embedded-workflows?clj

(has-embedded-workflows? node)

interceptor-orderclj

(interceptor-order definition & opts)

When :flow/order is :interceptor the function adds the leave-fn of all flows which are set to the end of the definition in reverse order of appearance to follow the interceptor chain logic.

See: http://pedestal.io/pedestal/0.7/guides/what-is-an-interceptor.html#_transition_from_enter_to_leave

When :flow/order is `:interceptor` the function adds the leave-fn of all flows
which are set to the end of the definition in reverse order of appearance
to follow the interceptor chain logic.

See: http://pedestal.io/pedestal/0.7/guides/what-is-an-interceptor.html#_transition_from_enter_to_leave
raw docstring

linear-orderclj

(linear-order definition & opts)

set-log-fnclj

(set-log-fn wf log-fn)

unload-workflowclj

(unload-workflow wf)

validate-topologyclj

(validate-topology definition)

Checks that the entries of the workflow definition to be processed by workflow-factory is a seq, isn't empty, has a recognized type, any dependent workflow is loaded.

Checks that the entries of the workflow definition to be processed by `workflow-factory`
is a seq, isn't empty, has a recognized type, any dependent workflow is loaded.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries