(evaluate {:workflow/keys [id log-fn] :as workflow} value)Uses the runtime stream of a flows entity to process the value
Uses the runtime stream of a flows entity to process the value
(stream {:workflow/keys [repeat-n source default-fn log-fn]
:or {repeat-n nil}
:as workflow}
runtime-arg)Invokes the workflow operating on its streams to execute as a synchronous operation returning a vector of the results.
Notes
The operation is in two phases populating the sink with the passed argument using the workflow options and the take phase which populates the output vector.
Unless specified by return-n, the operation will return all pending values from
the workflow source.
Options
run will put-all! when the runtime argument is a seqInvokes the workflow operating on its streams to execute as a synchronous operation returning a vector of the results. Notes The operation is in two phases populating the sink with the passed argument using the workflow options and the take phase which populates the output vector. Unless specified by `return-n`, the operation will return all pending values from the workflow source. Options - expand When true `run` will `put-all!` when the runtime argument is a seq - repeat-n n copies of the passed argument is added before the take phase. - put-timeout Will wait X milliseconds before throwing an exception during put operations. - take-timeout Will wait X milliseconds before throwing an exception during take operations.
(try-put! {:workflow/keys [id sink expand put-timeout log-fn]
:or {expand false}}
value)Attempts to put the value into the workflow stream handling timeout and expand options
Attempts to put the value into the workflow stream handling timeout and expand options
(try-take! {:workflow/keys [id take-timeout source log-fn]})cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |