Clojure only.

missinterpret.flows.invoke


streamclj

(stream {:workflow/keys [expand repeat-n put-timeout take-timeout sink source
                         log-fn]
         :or {expand false repeat-n nil}
         :as workflow}
        runtime-arg)

Invokes the workflow operating on its streams to execute as a synchronous operation returning a vector of the results.

Notes

The operation is in two phases populating the sink with the passed argument using the workflow options and the take phase which populates the output vector.

Unless specified by return-n, the operation will return all pending values from the workflow source.

Options

  • expand When true run will put-all! when the runtime argument is a seq
  • repeat-n n copies of the passed argument is added before the take phase.
  • put-timeout Will wait X milliseconds before throwing an exception during put operations.
  • take-timeout Will wait X milliseconds before throwing an exception during take operations.
Invokes the workflow operating on its streams to execute as a synchronous
operation returning a vector of the results.

Notes

The operation is in two phases populating the sink with the passed argument
using the workflow options and the take phase which populates the output
vector.

Unless specified by `return-n`, the operation will return all pending values from
the workflow source.

Options
 - expand       When true `run` will `put-all!` when the runtime argument is a seq
 - repeat-n     n copies of the passed argument is added before the take phase.
 - put-timeout  Will wait X milliseconds before throwing an exception during put operations.
 - take-timeout Will wait X milliseconds before throwing an exception during take operations.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries