(new-interceptor wf)(new-interceptor wf leave-fn)(new-interceptor wf leave-fn error-fn)Returns an interceptor with an enter function which returns the result of a workflow which processes the context.
Returns an interceptor with an enter function which returns the result of a workflow which processes the context.
(to-flow interceptor)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |