(defroute p-route & opts)Define a Flows-compatible Pedestal route.
Options are all available attributes which conform to the WorkflowOpts spec.
Define a Flows-compatible Pedestal route. Options are all available attributes which conform to the WorkflowOpts spec.
(flows p-route)Returns a vector of the flows defined by the defined route that is the workflow definition.
Returns a vector of the flows defined by the defined route that is the workflow definition.
(route-workflow p-route definition opts)(wf-definition func)Converts the interceptor 'definition' into a vector of flows
Converts the interceptor 'definition' into a vector of flows
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |