Constructor for the all flows, workflows and pedestal routes which define the catalog of runtime system.
Constructor for the all flows, workflows and pedestal routes which define the catalog of runtime system.
(definition)(definition {:keys [flows workflows routes log-fn args] :as system-args})(definition flow-defs wf-defs)(definition flow-defs wf-defs routes)(definition flow-defs wf-defs routes log-fn)(definition flow-defs wf-defs routes log-fn wf-default-args)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |