Clojure only.

missinterpret.flows.system.constructors

Constructor for the all flows, workflows and pedestal routes which define the catalog of runtime system.

Constructor for the all flows, workflows and pedestal routes
which define the catalog of runtime system.
raw docstring

definitionsclj

(definitions)
(definitions wf-defs)
(definitions flow-defs wf-defs)
(definitions flow-defs wf-defs wf-default-args)
(definitions flow-defs wf-defs wf-default-args log-fn)
(definitions flow-defs wf-defs wf-default-args log-fn routes)

cljdoc builds & hosts documentation for Clojure/Script libraries