missinterpret.flows.test.helpers


flowclj

(flow flow in out)

Uses clojure.test to validate that the Flow is valid, can be loaded and returns the expected output.

Uses `clojure.test` to validate that the Flow is valid, can be loaded
and returns the expected output.
raw docstring

start-fixtureclj

(start-fixture flows-definition f)

A fixture to be used with clojure.test/use-fixtures which ensures that the flows system is loaded the flows-definition for the scope of the test(s).

A fixture to be used with `clojure.test/use-fixtures` which
ensures that the flows system is loaded the flows-definition
for the scope of the test(s).
raw docstring

state-clean-fixtureclj

(state-clean-fixture f)

A fixture to be used with clojure.test/use-fixtures which ensures that the flows system state is not loaded for the scope of the test(s).

A fixture to be used with `clojure.test/use-fixtures` which
ensures that the flows system state is not loaded for the scope
of the test(s).
raw docstring

workflowclj

(workflow workflow in out)

Uses clojure.test to validate that the Workflow is valid, can be loaded and returns the expected output.

Important If the workflow's definition has any references either directly or via embedded workflows the flows system must be started with the dependencies.

Use the start-fixture with clojure.test/use-fixtures feature. Example:

(use-fixtures :once (partial start-fixture my-flows-definition))

Uses `clojure.test` to validate that the Workflow is valid, can be loaded
and returns the expected output.

*Important*
If the workflow's definition has any references either directly
or via embedded workflows the flows system must be started with
the dependencies.

Use the `start-fixture` with `clojure.test/use-fixtures` feature.
Example:

(use-fixtures :once (partial start-fixture my-flows-definition))
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries