(arity f)Returns the maximum arity of:
#() and (fn []).map or +.#'->.Returns :variadic if the function/macro is variadic.
Returns the maximum arity of: - anonymous functions like `#()` and `(fn [])`. - defined functions like `map` or `+`. - macros, by passing a var like `#'->`. Returns `:variadic` if the function/macro is variadic.
(assoc-if m k v)Assoc if the value is not nil
Assoc if the value is not nil
(either x default)Returns x if not nil, default otherwise.
Returns x if not nil, default otherwise.
(exclude m schema)Returns a map which excludes all keywords from the malli schema.
Returns a map which excludes all keywords from the malli schema.
(extract m schema)Returns a map of all keywords from the malli schema
Returns a map of all keywords from the malli schema
(keys schema)Returns all keys from a malli schema
Returns all keys from a malli schema
(keyword+ namesp n)Version of clojure.core/keyword which handles
non-string namespace arguments.
Behaviour:
Version of `clojure.core/keyword` which handles non-string namespace arguments. Behaviour: - If the name is a keyword uses the keyword name - If the namespace part is a fully qualified keyword it uses its namespace - If not a keyword or a string, strings it
(merge-if a b)Slightly safer version of merge. Merges b into a if they are both maps. Caution - does not throw an exception if they aren't.
Slightly safer version of merge. Merges b into a if they are both maps. Caution - does not throw an exception if they aren't.
(merge-opts m o)If variable options existing it merges them into the map
If variable options existing it merges them into the map
(only? m schema)Does the argument map only contain the keys of the given schema?
Does the argument map only contain the keys of the given schema?
(opts o)Converts variable arg options into a map. i.e. [a b & opts]
Handles nested options. i.e. [[:a :A]]
Throws
Converts variable arg options into a map. i.e. [a b & opts] Handles nested options. i.e. [[:a :A]] Throws - If arg is not a seq - If 'root' vector does not conform to missinterpret.flows.spec/Options spec.
(reduce-thread-var rfn coll var)A version of reduce that changes the argument order to make it compatible with thread last when you want to reduce on a different collection adding to a previous coll.
A version of reduce that changes the argument order to make it compatible with thread last when you want to reduce on a different collection adding to a previous coll.
(set-ns m nspace & {:keys [keep-qualified]})Sets the namespace of the top-level keys of the map to the argument ns.
Sets the namespace of the top-level keys of the map to the argument ns.
(take-range coll range)Takes a range from the coll. Behaviour:
Takes a range from the coll. Behaviour: - Range argument is an integer takes that number - If it is a vector of [start end] takes the elements from the coll between those values
(try-put-all! sink arg-seq timeout timeout-val)Takes a sequence argument and attempts to put each. Matches the semantics of stream/try-put!
Takes a sequence argument and attempts to put each. Matches the semantics of stream/try-put!
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |