missinterpret.flows.utils


assoc-ifclj

(assoc-if m k v)

Assoc if the value is not nil

Assoc if the value is not nil
raw docstring

eitherclj

(either x default)

Returns x if not nil, default otherwise.

Returns x if not nil, default otherwise.
raw docstring

excludeclj

(exclude m schema)

Returns a map which excludes all keywords from the malli schema.

Returns a map which excludes all keywords from the malli schema.
raw docstring

extractclj

(extract m schema)

Returns a map of all keywords from the malli schema

Returns a map of all keywords from the malli schema
raw docstring

keysclj

(keys schema)

merge-ifclj

(merge-if a b)

Slightly safer version of merge. Merges b into a if they are both maps. Caution - does not throw an exception if they aren't.

Slightly safer version of merge. Merges b into a if they are both maps.
Caution - does not throw an exception if they aren't.
raw docstring

merge-optsclj

(merge-opts m o)

only?clj

(only? m schema)

Does the argument map only contain the keys of the given schema?

Does the argument map only contain the keys of the given schema?
raw docstring

optsclj

(opts o)

Converts a seq into a map.

Intended for options to a function. i.e. [a b & opts] Handles nested options. i.e. [[:a :A]]

Throws

  • If arg is not a seq
  • If 'root' vector does not conform to missinterpret.flows.spec/Options spec.
Converts a seq into a map.

 Intended for options to a function. i.e. [a b & opts]
 Handles nested options. i.e. [[:a :A]]

Throws
 - If arg is not a seq
 - If 'root' vector does not conform to missinterpret.flows.spec/Options
   spec.
raw docstring

reduce-thread-varclj

(reduce-thread-var rfn coll var)

A version of reduce that changes the argument order to make it compatible with thread last when you want to reduce on a different collection adding to a previous coll.

A version of reduce that changes the argument order to make it
compatible with thread last when you want to reduce on a different
collection adding to a previous coll.
raw docstring

set-nsclj

(set-ns m nspace & {:keys [keep-qualified]})

Sets the namespace of the top-level keys of the map to the argument ns.

Sets the namespace of the top-level keys of the map to the argument ns.
raw docstring

take-rangeclj

(take-range coll range)

try-put-all!clj

(try-put-all! sink arg-seq timeout timeout-val)

Takes a sequence argument and attempts to put each. Matches the semantics of stream/try-put!

Takes a sequence argument and attempts to put
each. Matches the semantics of stream/try-put!
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries